version 11.0
log using "C:\matt\working_papers\religion\social\replication\data_analysis\aggregate\aggregate_religious_participation.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      aggregate_religious_participation.do            *;
*       Date:           February 5, 2013                                *;
*       Author:         MRG                                             *;
*       Purpose:      	Take aggregate_religious_participation.dta and  *;
*                       and produce results in Table 1 as well as       *;
*                       support for the other quantitative claims made  *;
*                       about aggregate religious participation.        *;
* 	    Input File:     aggregate_religious_participation.dta           *;
*       Output File:    aggregate_religious_participation.log           *;
*       Data Output:    none                                            *;             
*       Previous file:  aggregate_religious_participation.dta           *;
*       Machine:        office computer                 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 400m;

use "C:\matt\working_papers\religion\social\replication\data_analysis\aggregate\aggregate_religious_participation.dta", clear;

set more off;

sum;

desc;

corr hdi gdp1000;
corr lhdi lgdp1000;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Figure 1                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Check that negative relationship is not the result of the few   *;
*       observations that have low HDI and high religious participation.*;
*     ****************************************************************  *;

regress attend_religious_services hdi;
regress attend_religious_services hdi if hdi>0.5;
regress attend_religious_services hdi if hdi>0.6;
regress attend_religious_services hdi if hdi>0.7;
regress attend_religious_services hdi if hdi>0.8;
regress attend_religious_services hdi if hdi>0.9;

regress attend_religious_services lhdi;
regress attend_religious_services lhdi if hdi>0.5;
regress attend_religious_services lhdi if hdi>0.6;
regress attend_religious_services lhdi if hdi>0.7;
regress attend_religious_services lhdi if hdi>0.8;
regress attend_religious_services lhdi if hdi>0.9;

*     ****************************************************************  *;
*       Coefficients are always negative.  They are also statistically  *;
*       significant in all cases except when we limit our observations  *;
*       to those with an HDI score greater than 0.9.  This is not       *;
*       surprising given the small sample size and limited variation in *;
*       our independent variable at this stage.                         *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Table 1                                                         *;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress attend_religious_services lhdi government_regulation social_regulation   
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);

regress attend_religious_services lhdi government_regulation social_regulation  
        inequality_gini communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);
        
regress attend_religious_services lgdp1000 government_regulation social_regulation  
        inequality_gini communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave2 wave3 wave4, cluster(ccode);
        
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Replication of Table 1 complete                                 *;
*     ****************************************************************  *;
*     ****************************************************************  *;

log close;
        
*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;



