version 11.0
log using "C:\matt\working_papers\religion\social\replication\data_analysis\individual\individual_religious_participation.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      individual_religious_participation.do           *;
*       Date:           February 8, 2013                                *;
*       Author:         MRG                                             *;
*       Purpose:      	Take individual_religious_participation.dta     *;
*                       and produce results in Table 2 as well as       *;
*                       support for the other quantitative claims made  *;
*                       about individual religious participation.       *;
* 	    Input File:     individual_religious_participation.dta          *;
*       Output File:    individual_religious_participation.log          *;
*       Data Output:    none                                            *;             
*       Previous file:  individual_religious_participation.dta          *;
*       Machine:        office computer                 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 400m;

use "C:\matt\working_papers\religion\social\replication\data_analysis\individual\individual_religious_participation.dta", clear;

set more off;

sum;

desc;

*     ****************************************************************  *;
*       Create a panel ID variable.                                     *;
*     ****************************************************************  *;

egen idn=concat(year ccode);
encode idn, gen(id);

xtset id;

xtsum attend_religious_services;

xttab  attend_religious_services;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Table 2                                                         *;
*     ****************************************************************  *;
*     ****************************************************************  *;

xtreg attend_religious_services lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
xtreg attend_religious_services income_level lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;       
        
xtreg attend_religious_services male lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;        
        
xtreg attend_religious_services age65 lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
xtreg attend_religious_services highest_education lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
xtreg attend_religious_services income_level male age65 highest_education lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;       
        
*     ****************************************************************  *;
*     ****************************************************************  *;
*       To find the number of countries and not the country-survey,     *;
*       place the random effects on the country and look at number of   *;
*       groups.                                                         *;
*     ****************************************************************  *;
*     ****************************************************************  *;

xtreg attend_religious_services lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
xtreg attend_religious_services income_level lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;       
        
xtreg attend_religious_services male lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;        
        
xtreg attend_religious_services age65 lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
xtreg attend_religious_services highest_education lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
xtreg attend_religious_services income_level male age65 highest_education lhdi  inequality_gini  
        government_regulation  social_regulation
        communist postcommunist roman_catholic_alesina protestant_alesina muslim_alesina
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe
        wave1 wave2 wave3 wave4, i(ccode) theta;
       
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Replication of Table 2 complete                                 *;
*     ****************************************************************  *;
*     ****************************************************************  *;

log close;
        
*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;
 
