version 11.0
log using "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism_figure1.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      social_conservatism_figure1.do                  *;
*       Date:           February 12, 2013                               *;
*       Author:         MRG                                             *;
*       Purpose:      	Take social_conservatism.dta and produce        *;
*                       plots for Figure 2.                             *;
* 	    Input File:     social_conservatism.dta                         *;
*       Output File:    social_conservatism_figure.log                  *;
*       Data Output:    none                                            *;             
*       Previous file:  social_conservatism.dta                         *;
*       Machine:        office computer                 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 400m;

use "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism.dta", clear;

set more off;

sum;

desc;

*     ****************************************************************  *;
*       Create a panel ID variable.                                     *;
*     ****************************************************************  *;

egen idn=concat(year ccode);
encode idn, gen(id);
       
*     ****************************************************************  *;       
*     ****************************************************************  *;
*       Produce Figure 2.                                               *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Figure 2a.                                                      *;
*     ****************************************************************  *;

xtreg left_right attend_religious_services hdi attendance_hdi 
        income_level male highest_education age  
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

gen yline=0;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.1 -0.05 0 0.05 0.1 0.15 0.2, nogrid axis(1) labsize(2)) 
             ylabel(0 1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
             
sum hdi if hdi>0.52;
sum hdi;

*     ****************************************************************  *;
*       96.3% of observations fall in region of significance.           *;
*     ****************************************************************  *;
                         
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 2b.                                                      *;
*     ****************************************************************  *;

xtreg divorce attend_religious_services hdi attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.2 -0.1 0 0.1 0.2 0.3, nogrid axis(1) labsize(2)) 
             ylabel(0  1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));

sum hdi if hdi>0.53;
sum hdi;

*     ****************************************************************  *;
*       94.0% of observations fall in region of significance.           *;
*     ****************************************************************  *;
           
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 2c.                                                      *;
*     ****************************************************************  *;

xtreg euthanasia attend_religious_services hdi attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.2 -0.1 0 0.1 0.2 0.3 0.4, nogrid axis(1) labsize(2)) 
             ylabel(0 1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                          
sum hdi if hdi<0.42;
sum hdi if hdi>0.55;
sum hdi;

*     ****************************************************************  *;
*      93.6% of observations fall in the region of significance.        *;
*      0.004% of observations fall in the wrong region of significance. *;
*     ****************************************************************  *;

drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 2d.                                                      *;
*     ****************************************************************  *;

xtreg abortion attend_religious_services hdi attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.2 -0.1 0 0.1 0.2 0.3 0.4, nogrid axis(1) labsize(2)) 
             ylabel(0 1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
             
sum hdi if hdi<0.46;
sum hdi if hdi>0.58;
sum hdi;

*     ****************************************************************  *;
*       92.8% of observations fall in the region of significance.       *;
*       2.8% of observations fall in the wrong region of significance.  *;
*     ****************************************************************  *;

drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 2e.                                                      *;
*     ****************************************************************  *;

xtreg suicide attend_religious_services hdi attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.2 -0.1 0 0.1 0.2 , nogrid axis(1) labsize(2)) 
             ylabel(0 1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
             
sum hdi if hdi<0.53;
sum hdi if hdi>0.62;
sum hdi;

*     ****************************************************************  *;
*       91.2% of observations fall in the region of significance.       *;
*       6% of observations fall in the wrong region of significance.    *;
*     ****************************************************************  *;

drop conbx consx ax upperx lowerx MV;


*     ****************************************************************  *;
*       Figure 2f.                                                      *;
*     ****************************************************************  *;

xtreg homosexuality attend_religious_services hdi attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*       Create marginal effect graph for religious participation across *;
*       hdi.                                                            *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>101;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<42;

*     ****************************************************************  *;
*       Calculate the marginal effect of religiosity.                   *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<97;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<97; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist hdi, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(0.4 0.5 0.6 0.7 0.8 0.9 1, nogrid labsize(2))  
             ylabel(-0.3 -0.2 -0.1 0 0.1 0.2 0.3, nogrid axis(1) labsize(2)) 
             ylabel(0 1 2 3 4 5 6 7 8,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
             
sum hdi if hdi<0.56;
sum hdi if hdi>0.65;
sum hdi;

*     ****************************************************************  *;
*       90.8% of observations fall in the region of significance.       *;
*       7.2% of observations fall in the wrong region of significance.  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;


