version 11.0
log using "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism_figure2.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      social_conservatism_figure2.do                  *;
*       Date:           February 12, 2013                               *;
*       Author:         MRG                                             *;
*       Purpose:      	Take social_conservatism.dta and produce        *;
*                       plots for Figure 3.                             *;
* 	    Input File:     social_conservatism.dta                         *;
*       Output File:    social_conservatism_figure.log                  *;
*       Data Output:    none                                            *;             
*       Previous file:  social_conservatism.dta                         *;
*       Machine:        office computer                 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 400m;

use "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism.dta", clear;

set more off;

sum;

desc;

*     ****************************************************************  *;
*       Create a panel ID variable.                                     *;
*     ****************************************************************  *;

egen idn=concat(year ccode);
encode idn, gen(id);
       
*     ****************************************************************  *;       
*     ****************************************************************  *;
*       Produce Figure 3.                                               *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Figure 3a.                                                      *;
*     ****************************************************************  *;

xtreg left_right hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

gen yline=0;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-5 -4 -3 2 -2 2 -1 2 0 2 1 2, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                                                                
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 3b.                                                      *;
*     ****************************************************************  *;

xtreg divorce hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-10 -8 -6 -4 -2 0, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
             
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 3c.                                                      *;
*     ****************************************************************  *;

xtreg euthanasia hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-12 -10 -8 -6 -4 -2 0, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                          
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 3d.                                                      *;
*     ****************************************************************  *;

xtreg abortion hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-10 -8 -6 -4 -2 0, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                          
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 3e.                                                      *;
*     ****************************************************************  *;

xtreg suicide hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-10 -9 -8 -7 -6 -5 -4 -3 -2 -1 0, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                                                                          
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       Figure 3f.                                                      *;
*     ****************************************************************  *;

xtreg homosexuality hdi attend_religious_services attendance_hdi income_level male highest_education age
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

*     ****************************************************************  *;
*      Create marginal effect graph for hdi across religious            *;
*      participation.                                                   *;
*     ****************************************************************  *;

generate MV=((_n-1)/100);

replace  MV=. if _n>801;

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

replace MV=. if _n<101;

*     ****************************************************************  *;
*       Calculate the marginal effect of hdi.                           *;
*     ****************************************************************  *;

gen conbx=b1+b3*MV if _n<802;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect.          *;
*     ****************************************************************  *;

gen consx=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<802; 

*     ****************************************************************  *;
*       Generate upper and lower bounds of the confidence interval.     *;
*     ****************************************************************  *;

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

graph twoway hist attend_religious_services, percent color(gs12) yaxis(2) 
        ||   line conbx   MV, clpattern(solid) clwidth(medium) clcolor(blue) clcolor(black) yaxis(1)  
        ||   line upperx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line lowerx  MV, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MV,  clwidth(thin) clcolor(black) clpattern(solid) 
        ||   ,  
             xlabel(1 2 3 4 5 6 7 8, nogrid labsize(2))  
             ylabel(-18 -16 -14 -12 -10 -8 -6 -4 -2 0, nogrid axis(1) labsize(2)) 
             ylabel(0 5 10 15 20 25,  axis(2) nogrid labsize(2)) 
             yscale(noline alt) 
             yscale(noline alt axis(2)) 
             xscale(noline) 
             legend(off) 
             yline(0, lcolor(black) lwidth(thin)) 
             xtitle("" , size(2.5)  ) 
             ytitle("", axis(2) size(2.5)) 
             xsca(titlegap(2)) 
             ysca(titlegap(2)) 
             scheme(s2mono) graphregion(fcolor(white));
                                    
drop conbx consx ax upperx lowerx MV;

*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;


